@@ -224,11 +224,9 @@ main (int argc, char **argv)
 
     gtk_init (&argc, &argv);
 
-    /* XXX - We could use a GtkDialog instead here, since this is
-     * really a simple dialog.
-     */
-    info = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    info = gtk_dialog_new ();
     gtk_window_set_title (GTK_WINDOW (info), _("About XFce 4"));
+    gtk_dialog_set_has_separator (GTK_DIALOG (info), FALSE);
     gtk_window_stick (GTK_WINDOW (info));
 
     logo_pb = inline_icon_at_size (xfce_logo_data, 48, 48);
@@ -236,7 +234,7 @@ main (int argc, char **argv)
 
     vbox2 = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox2);
-    gtk_container_add (GTK_CONTAINER (info), vbox2);
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (info)->vbox), vbox2, TRUE, TRUE, 0);
 
     /* header with logo */
     text =
@@ -270,21 +268,19 @@ main (int argc, char **argv)
     add_page (GTK_NOTEBOOK (notebook), _("GPL"), XFCE_GPL, TRUE);
 
     /* buttons */
-    buttonbox = gtk_hbutton_box_new ();
-    gtk_widget_show (buttonbox);
-    gtk_box_pack_start (GTK_BOX (vbox), buttonbox, FALSE, FALSE, BORDER);
-
-    info_ok_button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
-    gtk_widget_show (info_ok_button);
-    gtk_box_pack_start (GTK_BOX (buttonbox), info_ok_button, FALSE, FALSE, 0);
+    buttonbox = GTK_DIALOG (info)->action_area;
 
     info_help_button = gtk_button_new_from_stock (GTK_STOCK_HELP);
     gtk_widget_show (info_help_button);
     gtk_box_pack_start (GTK_BOX (buttonbox), info_help_button, FALSE, FALSE,
 			0);
 
+    info_ok_button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
+    gtk_widget_show (info_ok_button);
+    gtk_box_pack_start (GTK_BOX (buttonbox), info_ok_button, FALSE, FALSE, 0);
+
     gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (buttonbox),
-					info_ok_button, TRUE);
+					info_help_button, TRUE);
 
     g_signal_connect (info, "delete-event", G_CALLBACK (gtk_main_quit), NULL);
     g_signal_connect (info, "destroy-event",
